=======
Modules
=======

materials
=========

composites
----------
.. automodule:: material_mechanics.materials.composites
    :members:

elastic_materials
-----------------
.. automodule:: material_mechanics.materials.elastic_materials
    :members:

material_factories
------------------
.. automodule:: material_mechanics.materials.material_factories
    :members:

material_law
------------
.. automodule:: material_mechanics.materials.material_law
    :members:

strength
========

puck
----
.. automodule:: material_mechanics.strength.puck
    :members:

tools
=====

functions
---------
.. automodule:: material_mechanics.tools.functions
    :members:
